<?php

namespace Quivers\Components;
use Shopware\Components\Api\Exception as ApiException;
use Shopware\Models\Order\Detail as OrderDetailModel;
use Shopware\Models\Order\DetailStatus;
use Shopware\Models\Order\Order as OrderModel;

class Position
{
    /**
     * Order repository. Declared for an fast access to the order repository.
     *
     * @var \Shopware\Models\Order\Repository
     */
    public static $repository;

    public static $orderRepository;

    public function getRepository()
    {
        self::$repository = Shopware()->Models()->getRepository(OrderDetailModel::class);
        return self::$repository;
    }

    public function getOrderRepository()
    {
        self::$orderRepository = Shopware()->Models()->getRepository(OrderModel::class);
        return self::$orderRepository;
    }

    public function updateItem(\Enlight_Event_EventArgs $args)
	{
	    $shippingQuantity = 0;
		$controller = $args->getSubject();
        $request = $controller->Request();
        $response = $controller->Response();
        $tableName = $request->getParam("_table");
        if ($tableName != "s_order_details_attributes"){
            return;
        }
        $foreignKeyId = $request->getParam("_foreignKey");
        $amountRefunded = $request->getParam("__attribute_amount_refunded");
        $cancellationQuantity = $request->getParam("__attribute_cancellation_quantity");
        $quantityReturned = $request->getParam("__attribute_quantity_returned");
        $detail = $this->getRepository()->find($foreignKeyId);
        $sql = Shopware()->Db()->select()
            ->from('s_order_details_attributes')
            ->where('detailID = '. $foreignKeyId);
        $attributes = Shopware()->Db()->fetchAll($sql);
        foreach ($attributes[0] as $key => $value){
                $subStr = subStr($key, 0, 15);
                if (($subStr == "quantityshipped") and (!empty($value))){
                    $shippingQuantity = $shippingQuantity + $value;
                }
         }
        if (!$detail) {
            throw new ApiException\NotFoundException("Order Detail by id $id not found");
        }
        $quantity = $detail->getQuantity();
        $status = $detail->getStatus();

        if ($cancellationQuantity == $quantity){
            $status = 2;
        }
        elseif ($quantityReturned == $quantity){
            $status = 4;
        }
        elseif ($shippingQuantity == $quantity){
            $status = 3;
        }
        $status = Shopware()->Models()->find(DetailStatus::class, $status);
        $detail->setStatus($status);
        Shopware()->Models()->flush();
	}

	public function changedDateUpdate(\Enlight_Event_EventArgs $args){
            $controller = $args->getSubject();
            $request = $controller->Request();
            $action = $controller->Request()->getActionName();
            $id = $request->getParam("id");
            if (empty($id)){
                $id = $request->getParam("_foreignKey");
            }
            if (empty($id)){
                return;
            }
            if (($action == 'savePosition') or ($action == 'saveData')){
                if ($request->getParam('_table') == 's_order_details_attributes'){
                    $detail = $this->getRepository()->find($id);
                    $order = $detail->getOrder();
                }
                 if ($request->getParam('_table') == 's_order_attributes'){
                    $order = $this->getOrderRepository()->find($id);
                }
            }
            elseif (($action == 'save')){
                $order = $this->getOrderRepository()->find($id);
            }
            if (!$order) {
                throw new ApiException\NotFoundException("Order by order_id or detail_id $id not found");
            }
            $date = new \DateTime('now', new \DateTimeZone('UTC'));
            $date = ["changed" => $date];
            $order->setAttribute($date);
            Shopware()->Models()->flush();
	    }

	public function positionStatusUpdate(\Enlight_Event_EventArgs $args){
	    $controller = $args->getSubject();
            $request = $controller->Request();
            $orderId = $request->getParam("id");
            $status = $request->getParam("status");
            if (!$status){
                return ;
            }
            $orderData = $this->getOrderRepository()->find($orderId);
            if (!$orderData) {
                throw new ApiException\NotFoundException("Order by id $id not found");
            }
            $details = $orderData->getDetails();
            if ($status == 7){
                foreach ($details as $detail){
                    $status = Shopware()->Models()->find(DetailStatus::class, 3);
                    $detail->setStatus($status);
                }
                }
            elseif ($status == 4){
                 foreach ($details as $detail){
                    $status = Shopware()->Models()->find(DetailStatus::class, 2);
                    $detail->setStatus($status);
                }
                }
            elseif ($status == 36){
                 foreach ($details as $detail){
                    $status = Shopware()->Models()->find(DetailStatus::class, 4);
                    $detail->setStatus($status);
                }
            }
            Shopware()->Models()->flush();
	    }
    }