<?php

use Quivers\Models\Settings\QuiversSetting as QuiversSettingsModel;
use QUivers\Components\QuiversConfig;

class Shopware_Controllers_Backend_QuiversConfiguration extends Shopware_Controllers_Backend_Application
{
    protected $model = QuiversSettingsModel::class;

    public function getMarketplacesAction(){
        $service = $this->container->get('quivers_plugin.marketplaces_config');
        if (!$service){
            return;           
        }
        $taxSettings = $service->getMarketPlaces();
        $marketplaces =$taxSettings['marketPlaces'];
        $this->view->assign([
            'data' => $marketplaces,
            'total' => count($marketplaces),
        ]);
    }

    public function getClaimingGroupAction(){
        $service = $this->container->get('quivers_plugin.marketplaces_config');
        if (!$service){
            return;        
        }
        $taxSettings = $service->getClaimingPolicies();
        $claimingPolicy = $taxSettings['claimingPolicy'];
        $this->view->assign([
            'data' => $claimingPolicy,
            'total' => count($claimingPolicy),
        ]);
    }

    public function upcAction(){
        $request = $this->Request();
        $service = $this->container->get('dbal_connection');
        $upc_field = $request->getParam('upcField');
        $sql = 'UPDATE s_articles_attributes SET quivers_hidden_upc = ?';
        $service->executeUpdate($sql, [$upc_field]);
        $this->View()->assign('success', true);
    }

    public function validateAction(){
        $request = $this->Request();
        $service = $this->get('quivers_plugin.quivers_config');
        if (!$service){
            $this->View()->assign([
                'success' => false,
                'message' => "Unable to sync to Quivers. If the issue still persists, please contact enterprise@quivers.com for further assistance.",
            ]);
            return;                
        }
        $message = $service->profileCreate([
            'apikey'=>$request->getParam('apiKey'),
            'businessRefId'=>$request->getParam('businessRefId'),
            'baseUrl'=>$request->getParam('BaseUrl'),
            'basicAuth'=>$request->getParam('basicAuth'),
            'sandbox'=>$request->getParam('sanbox'),
            'enablePlugin'=>$request->getParam('enablePlugin')]
        );
        if($message != 'success'){
            $this->View()->assign([
                'success' => false,
                'message' => $message,
            ]);
            return;
        }
        $this->View()->assign('success', true);
    } 

    public function detailAction()
    {
        $settings = $this->getSettings();
        if ($settings !== null) {
            $this->view->assign('general_settings', $settings->toArray());
        }
        else{
            $settings = [];
            $this->view->assign('general_settings', $settings);

        }
    }

    public function getSettings()
    {
        /** @var QuiversSetting $generalSettings */
        $generalSettings = $this->getRepository()->findAll();
        return $generalSettings[0];
    }
}