<?php

namespace Quivers\Subscriber;

use Enlight\Event\SubscriberInterface;
use Quivers\Components\TaxCalculator;
use Quivers\Components\ConfigProvider;
use Enlight_Controller_ActionEventArgs as ActionEventArgs;

class Frontend implements SubscriberInterface
{
    private $session;
    private $taxCalculator;
    private $configProvider;
    

    public function __construct(TaxCalculator $taxCalculator, ConfigProvider $configProvider)
    {
       $this->taxCalculator = $taxCalculator;
       $this->configProvider = $configProvider;
       $this->session = Shopware()->Session();
    }

    public static function getSubscribedEvents()
    {
        return [
            'Enlight_Controller_Action_PostDispatchSecure_Frontend_Checkout' => ['quiversTax', -11],
            'Enlight_Controller_Action_PostDispatchSecure_Frontend_Address' => 'quiversCallback'
        ];
    }

    // get function for subscriber
    public function get($key)
    {
        return Shopware()->Container()->get($key);
    }

    // redirect function for subscriber
    public function redirect($url, array $options = [], ActionEventArgs $args)
    {
        $controller = $args->getSubject();
 
        $request = $controller->Request();
        $response = $controller->Response();
 
        if (is_array($url)) {
            $front = $this->get('front');
            $url = $front->Router()->assemble($url);
        }

        if (!preg_match('#^(https?|ftp)://#', $url)) {
            if (strpos($url, '/') !== 0) {
                $url = $request->getBaseUrl() . '/' . $url;
            }
            $uri = $request->getScheme() . '://' . $request->getHttpHost();
            $url = $uri . $url;
        }

        $response->setRedirect($url, empty($options['code']) ? 302 : (int) $options['code']);
    }
    
    //check if address is changed
    public function quiversCallback(ActionEventArgs $args){
        $controller = $args->getSubject();
        $request = $controller->Request();
        
        $allowedActions = ['ajaxSave', 'handleExtra'];
        
        $action = $controller->Request()->getActionName();
        $view = $controller->View();

        if (!in_array($action, $allowedActions, true)) {
            return;
        }
        
        $this->session['saveActionCheck'] = 1;
    }

    public function quiversTax(ActionEventArgs $args)
    {
        $controller = $args->getSubject();
 
        $request = $controller->Request();

        $allowedActions = ['confirm', 'shippingPayment', 'saveShippingPayment', 'finish'];
        $action = $controller->Request()->getActionName();
        $view = $controller->View();

        if($request->getParam("error_name")){
            $view->assign('quiversErrorMessage', $request->getParam("error_name"));
            $view->assign('quiversErrorName', $request->getParam("error_message"));
        }
        
        if (!in_array($action, $allowedActions, true)) {
            return;
        }
        $this->configProvider->getconfig($args);
        $this->taxCalculator->quivers_tax($args);
        
        //redirect if address is changed
        if($this->session['saveActionCheck'] === 1){
            $redirectData = [
                'controller' => 'checkout',
                'action' => 'shippingPayment',
            ];
            $this->session['saveActionCheck'] = 0;
            $this->redirect($redirectData, array(), $args);
        }
    }
}